# CompPhysUtils
## Collection of Python utilities for Computational Condensed Matter Physicists

CompPhysUtils is a library of utilities that automate and simplify certain mundane tasks so that you
can spend more time investigating physical phenomena and less time generating coordinates of various
clusters, deciding on details of plots etc.

The development is in early stages and is based on collection of code generated during the author's
PhD study. More code will be present in the future, as well as documentation.

CompPhysUtils aims to be highly configurable and highly extensible. As a library, it is distributed
under the LGPL v3 license, so that you can use it pretty much without restriction, but if you decide
to change its functionality or extended the code itself significantly, you are required to share it
with the community.
